@@ -1,12 +1,12 @@
 from typing import Optional, List, Union
 import time
 from hein_robots.robotics import Location, Twist, Wrench, Cartesian, Orientation, Units
-from hein_robots.base.robot_arms import RobotArm
+from hein_robots.base import robot_arms
 from hein_robots.base.actuators import Actuator
 from hein_robots.kinova.kortex import KortexConnection, Base_pb2, ControlConfig_pb2
 
 
-class KinovaGen3Arm(RobotArm):
+class KinovaGen3Arm(robot_arms.RobotArm):
     GRIPPER_VELOCITY_STOP_THRESHOLD = 0.01
 
     def __init__(self, host: str = '192.168.1.10', port: int = 10000, username: str = 'admin', password: str = 'admin', connect: bool = True,
@@ -61,7 +61,7 @@ class KinovaGen3Arm(RobotArm):
     @default_velocity.setter
     def default_velocity(self, value: float):
         if value < 0 or value > self.max_velocity:
-            raise KinovaGen3ArmInvalidVelocityError(f'Invalid velocity: {value} m/s, must be less than {self.max_velocity} m/s')
+            raise robot_arms.RobotArmInvalidVelocityError(f'Invalid velocity: {value} m/s, must be less than {self.max_velocity} m/s')
 
         self._default_velocity = value
 
@@ -200,29 +200,14 @@ class KinovaGen3Arm(RobotArm):
 
         self.connection.control_client.SetToolConfiguration(tool_config)
 
-    def move(self, x: Optional[float] = None, y: Optional[float] = None, z: Optional[float] = None,
-             rx: Optional[float] = None, ry: Optional[float] = None, rz: Optional[float] = None,
-             velocity: Optional[float] = None, acceleration: Optional[float] = None,
-             relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
-        if not relative:
-            location = Location(
-                x=self.location.position.x if x is None else x,
-                y=self.location.position.y if y is None else y,
-                z=self.location.position.z if z is None else z,
-                ry=self.location.orientation.ry if ry is None else ry,
-                rx=self.location.orientation.rx if rx is None else rx,
-                rz=self.location.orientation.rz if rz is None else rz,
-            )
-        else:
-            location = Location(x or 0, y or 0, z or 0, rx or 0, ry or 0, rz or 0)
-
-        self.move_to_location(location, velocity=velocity, acceleration=acceleration, relative=relative, wait=wait, timeout=timeout)
+    def wait(self, timeout: Optional[float] = None):
+        self.connection.wait_for_action_end(timeout)
 
     def move_to_location(self, location: Location,
                          velocity: Optional[float] = None, acceleration: Optional[float] = None,
                          relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
         if velocity is not None and velocity > self.max_velocity:
-            raise KinovaGen3ArmInvalidVelocityError(f'Invalid velocity: {velocity} m/s, must be less than {self.max_velocity} m/s')
+            raise robot_arms.RobotArmInvalidVelocityError(f'Invalid velocity: {velocity} m/s, must be less than {self.max_velocity} m/s')
 
         action = Base_pb2.Action()
 
@@ -253,14 +238,14 @@ class KinovaGen3Arm(RobotArm):
             self.move_to_location(location, velocity=velocity, acceleration=acceleration,
                                   relative=relative, wait=wait, timeout=timeout)
 
-    def move_joints(self, *joint_positions: float,
+    def move_joints(self, joint_positions: List[float],
                     velocity: Optional[float] = None, acceleration: Optional[float] = None,
                     relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
         if len(joint_positions) != self.joint_count:
-            raise KinovaGen3ArmInvalidJointsError(f'Invalid number of joint angles ({len(joint_positions)}), must be {self.joint_count}')
+            raise robot_arms.RobotArmInvalidJointsError(f'Invalid number of joint angles ({len(joint_positions)}), must be {self.joint_count}')
 
         if velocity is not None and velocity > self.max_velocity:
-            raise KinovaGen3ArmInvalidVelocityError(f'Invalid velocity: {velocity} m/s, must be less than {self.max_velocity} m/s')
+            raise robot_arms.RobotArmInvalidVelocityError(f'Invalid velocity: {velocity} m/s, must be less than {self.max_velocity} m/s')
 
         action = Base_pb2.Action()
 
@@ -280,7 +265,7 @@ class KinovaGen3Arm(RobotArm):
                       velocity: Optional[float] = None, acceleration: Optional[float] = None,
                       relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
         if velocity is not None and velocity > self.max_velocity:
-            raise KinovaGen3ArmInvalidVelocityError(f'Invalid velocity: {velocity} m/s, must be less than {self.max_velocity} m/s')
+            raise robot_arms.RobotArmInvalidVelocityError(f'Invalid velocity: {velocity} m/s, must be less than {self.max_velocity} m/s')
 
         action = Base_pb2.Action()
 
@@ -325,7 +310,7 @@ class KinovaGen3Arm(RobotArm):
             if abs(self.gripper_velocity) < self.GRIPPER_VELOCITY_STOP_THRESHOLD:
                 return
 
-        raise KinovaGen3ArmGripperTimeoutError(f'Timeout while waiting for gripper to stop')
+        raise robot_arms.RobotArmGripperTimeoutError(f'Timeout while waiting for gripper to stop')
 
     def open_gripper(self, position: Optional[Union[float, bool]] = None, wait: bool = True, timeout: Optional[float] = None):
         if position is None:
@@ -344,27 +329,3 @@ class KinovaGen3Arm(RobotArm):
         if wait:
             time.sleep(0.05)
             self.wait_for_gripper_stop(timeout=timeout)
-
-    def close_gripper(self, position: Optional[Union[float, bool]] = None, wait: bool = True, timeout: Optional[float] = None):
-        if position is None:
-            position = False
-        elif isinstance(position, bool):
-            position = not position
-
-        self.open_gripper(position, wait=wait, timeout=timeout)
-
-
-class KinovaGen3ArmError(Exception):
-    pass
-
-
-class KinovaGen3ArmInvalidJointsError(KinovaGen3ArmError):
-    pass
-
-
-class KinovaGen3ArmInvalidVelocityError(KinovaGen3ArmError):
-    pass
-
-
-class KinovaGen3ArmGripperTimeoutError(KinovaGen3ArmError):
-    pass
